resttools.set_vertical_positioning_pitch_on_rest
================================================

.. autofunction:: abjad.tools.resttools.set_vertical_positioning_pitch_on_rest.set_vertical_positioning_pitch_on_rest
